<h2 align="center">FAST movie processor</h2>

<p align="center">
<a href="https://gitlab.com/fastspm/pyfastspm/-/commits/release"><img alt="pipeline status" src="https://gitlab.com/fastspm/pyfastspm/badges/release/pipeline.svg" /></a>
<a href="https://pypi.org/project/pyfastspm/"><img alt="PyPI" src="https://img.shields.io/pypi/v/pyfastspm"></a>
<a href="https://anaconda.org/conda-forge/pyfastspm"><img alt="Conda (channel only)" src="https://img.shields.io/conda/vn/conda-forge/pyfastspm"></a>
<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
<a href="https://github.com/fastspm/pyfastspm/blob/release/LICENSE"><img alt="Conda - License" src="https://img.shields.io/conda/l/conda-forge/pyfastspm?color=orange"></a>
<a href="https://doi.org/10.5281/zenodo.6824215"><img src="https://zenodo.org/badge/DOI/10.5281/zenodo.6824215.svg" alt="DOI"></a>
</p>

_A python package for loading, processing and exporting scanning tunneling microscopy movies acquired with the FAST module._

The package documentation can be found at [this link](http://fastspm.gitlab.io/pyfastspm/).
